@@ -1,8 +1,7 @@
-import collections.abc
 import functools
 import importlib
 import logging
-from typing import Any, List
+from typing import Any, List, Mapping, Optional
 
 from tavern._core import exceptions
 
@@ -22,7 +21,7 @@ def is_ext_function(block: Any) -> bool:
     return isinstance(block, dict) and block.get("$ext", None) is not None
 
 
-def get_pykwalify_logger(module):
+def get_pykwalify_logger(module: Optional[str]) -> logging.Logger:
     """Get logger for this module
 
     Have to do it like this because the way that pykwalify load extension
@@ -36,7 +35,7 @@ def get_pykwalify_logger(module):
     return logging.getLogger(module)
 
 
-def _getlogger():
+def _getlogger() -> logging.Logger:
     return get_pykwalify_logger("tavern._core.extfunctions")
 
 
@@ -80,7 +79,7 @@ def import_ext_function(entrypoint: str):
     return function
 
 
-def get_wrapped_response_function(ext: collections.abc.Mapping):
+def get_wrapped_response_function(ext: Mapping):
     """Wraps a ext function with arguments given in the test file
 
     This is similar to functools.wrap, but this makes sure that 'response' is
@@ -107,7 +106,7 @@ def get_wrapped_response_function(ext: collections.abc.Mapping):
     return inner
 
 
-def get_wrapped_create_function(ext: collections.abc.Mapping):
+def get_wrapped_create_function(ext: Mapping):
     """Same as get_wrapped_response_function, but don't require a response"""
 
     func, args, kwargs = _get_ext_values(ext)
@@ -123,7 +122,7 @@ def get_wrapped_create_function(ext: collections.abc.Mapping):
     return inner
 
 
-def _get_ext_values(ext: collections.abc.Mapping):
+def _get_ext_values(ext: Mapping):
     args = ext.get("extra_args") or ()
     kwargs = ext.get("extra_kwargs") or {}
     try:
@@ -136,7 +135,7 @@ def _get_ext_values(ext: collections.abc.Mapping):
     return func, args, kwargs
 
 
-def update_from_ext(request_args: dict, keys_to_check: List[str]):
+def update_from_ext(request_args: dict, keys_to_check: List[str]) -> None:
     """
     Updates the request_args dict with any values from external functions
 
