@@ -1,12 +1,10 @@
-import collections.abc
 from contextlib import ExitStack
 import copy
 from copy import deepcopy
-from distutils.util import strtobool  # pylint: disable=deprecated-module
 import functools
 import logging
-import os
-from typing import List
+import pathlib
+from typing import List, Mapping, MutableMapping
 
 import box
 
@@ -23,14 +21,13 @@ from .dict_util import format_keys, get_tavern_box
 from .pytest import call_hook
 from .pytest.config import TestConfig
 from .report import attach_stage_content, wrap_step
+from .strtobool import strtobool
 from .testhelpers import delay, retry
 
 logger = logging.getLogger(__name__)
 
 
-def _resolve_test_stages(
-    test_spec: collections.abc.Mapping, available_stages: collections.abc.Mapping
-):
+def _resolve_test_stages(test_spec: Mapping, available_stages: Mapping):
     # Need to get a final list of stages in the tests (resolving refs)
     test_stages = []
     for raw_stage in test_spec["stages"]:
@@ -59,7 +56,7 @@ def _resolve_test_stages(
 def _get_included_stages(
     tavern_box: box.Box,
     test_block_config: TestConfig,
-    test_spec: collections.abc.Mapping,
+    test_spec: Mapping,
     available_stages: List[dict],
 ) -> List[dict]:
     """
@@ -112,10 +109,10 @@ def _get_included_stages(
 
 
 def run_test(
-    in_file: os.PathLike,
-    test_spec: collections.abc.MutableMapping,
+    in_file: pathlib.Path,
+    test_spec: MutableMapping,
     global_cfg: TestConfig,
-):
+) -> None:
     """Run a single tavern test
 
     Note that each tavern test can consist of multiple requests (log in,
@@ -217,8 +214,8 @@ def run_test(
 
 
 def _calculate_stage_strictness(
-    stage: dict, test_block_config: TestConfig, test_spec: collections.abc.Mapping
-):
+    stage: dict, test_block_config: TestConfig, test_spec: Mapping
+) -> StrictLevel:
     """Figure out the strictness for this stage
 
     Can be overridden per stage, or per test
@@ -279,10 +276,10 @@ def _calculate_stage_strictness(
 
 
 def run_stage(
-    sessions: collections.abc.Mapping,
-    stage: collections.abc.Mapping,
+    sessions: Mapping,
+    stage: Mapping,
     test_block_config: TestConfig,
-):
+) -> None:
     """Run one stage from the test
 
     Args:
