@@ -14,6 +14,7 @@ from tavern._core.dict_util import check_keys_match_recursive
 from tavern._core.loader import ANYTHING
 from tavern._core.pytest.newhooks import call_hook
 from tavern._core.report import attach_yaml
+from tavern._core.strict_util import StrictSetting
 from tavern.response import BaseResponse
 
 from .client import MQTTClient
@@ -24,7 +25,7 @@ _default_timeout = 1
 
 
 class MQTTResponse(BaseResponse):
-    def __init__(self, client: MQTTClient, name, expected, test_block_config):
+    def __init__(self, client: MQTTClient, name, expected, test_block_config) -> None:
         super().__init__(name, expected, test_block_config)
 
         self._client = client
@@ -135,7 +136,7 @@ class MQTTResponse(BaseResponse):
         return saved
 
     def _await_messages_on_topic(
-        self, topic, expected
+        self, topic: str, expected
     ) -> Tuple[List["_ReturnedMessage"], List[str]]:
         """
         Waits for the specific message
@@ -235,7 +236,7 @@ class _ReturnedMessage:
 
 
 class _MessageVerifier:
-    def __init__(self, test_block_config, expected):
+    def __init__(self, test_block_config, expected) -> None:
         self.expires = time.time() + expected.get("timeout", _default_timeout)
 
         self.expected = expected
@@ -244,11 +245,11 @@ class _MessageVerifier:
         )
 
         test_strictness = test_block_config.strict
-        self.block_strictness = test_strictness.setting_for("json")
+        self.block_strictness: StrictSetting = test_strictness.option_for("json")
 
         # Any warnings to do with the request
         # eg, if a message was received but it didn't match, message had payload, etc.
-        self.warnings = []
+        self.warnings: List[str] = []
 
     def is_valid(self, msg: MQTTMessage) -> bool:
 
