@@ -1,13 +1,15 @@
 from abc import abstractmethod
 import logging
 
+import box
+
 logger = logging.getLogger(__name__)
 
 
 class BaseRequest:
     @property
     @abstractmethod
-    def request_vars(self):
+    def request_vars(self) -> box.Box:
         """
         Variables used in the request
 
